<?php
add_action( 'wp_enqueue_scripts', function() {
  wp_enqueue_style( 'style', get_stylesheet_uri() );
  wp_enqueue_script('jquery');
 	wp_enqueue_script( 'footer_js', get_template_directory_uri() . '/js/footer-bundle.js', null, 1.0, true );
});

add_filter( 'excerpt_length', function() {
	return 22;
});

// Theme setup
add_action( 'after_setup_theme', function() {
	// Handle Titles
	add_theme_support( 'title-tag' );

	// Add featured image support
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'small-thumbnail', 720, 720, true );
	add_image_size( 'square-thumbnail', 80, 80, true );
  add_image_size( 'banner-image', 1024, 1024, true );

  load_theme_textdomain( 'simple-campaign', get_template_directory() . '/languages' );

  add_theme_support( 'post-thumbnails' );

  register_nav_menus( array(
    'menu-1' => esc_html__( 'Primary', 'simple_campaign' ),
  ) );

  add_theme_support( 'html5', array(
    'search-form',
    'comment-form',
    'comment-list',
    'gallery',
    'caption',
  ) );

  add_theme_support( 'custom-background', apply_filters( 'simple_campaign_custom_background_args', array(
    'default-color' => 'ffffff',
    'default-image' => '',
  ) ) );

  add_theme_support( 'customize-selective-refresh-widgets' );

  add_theme_support( 'custom-logo', array(
    'height'      => 250,
    'width'       => 250,
    'flex-width'  => true,
    'flex-height' => true,
  ) );

});

show_admin_bar( false );

// Checks if there are any posts in the results
function is_search_has_results() {
	return 0 != $GLOBALS['wp_query']->found_posts;
}

add_action( 'after_setup_theme', function() {
	$GLOBALS['content_width'] = apply_filters( 'simple_campaign_content_width', 640 );
}, 0);

add_action( 'widgets_init', function() {
	register_sidebar( array(
		'name'          => esc_html__( 'Footer', 'simple_campaign' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'simple_campaign' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
  ) );
  register_sidebar( array(
		'name'          => esc_html__( 'Home Pre-Footer', 'simple_campaign' ),
		'id'            => 'front-page-footer',
		'description'   => esc_html__( 'Add widgets here.', 'simple_campaign' ),
		'before_widget' => '<div id="%1$s" class="widget column %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="column-title">',
		'after_title'   => '</h2>',
	) );
});

// includes
require_once dirname(__FILE__).'/inc/index.php';



function ti_custom_javascript() {
    ?>
        <script>
            // prefill form inputs from query parameters (?input_name=value)
			var params = new URLSearchParams(window.location.search);
			for (var [param_key, param_value] of params.entries()) {
				var formElement = document.getElementById(param_key);
				if (formElement) {
				    if (['checkbox', 'radio'].includes(formElement.type)) {
					    formElement.checked = param_value;
				    } else {
					    formElement.value = param_value;
				    }
				}
			}
        </script>
    <?php
}
add_action('wp_footer', 'ti_custom_javascript');

// add minimum price on congress tickets for members
add_filter( 'gform_field_validation_19_9', 'gf_user_defined_price_validation_tickets_members', 10, 4 );
function gf_user_defined_price_validation_tickets_members( $result, $value, $form, $field ) {
    //change value for price field to just be numeric (strips off currency symbol, etc.) using Gravity Forms to_number function
    $number = GFCommon::to_number( $value, 'EUR' );
    GFCommon::log_debug( __METHOD__ . '(): User Defined Price Submitted: ' . $number );
  
	$min_amount = 1.00;
    if ( $result['is_valid'] && $number < $min_amount ) {
        $result['is_valid'] = false;
        $result['message'] = 'Je kan geen bedrag invullen lager dan '.$min_amount.' euro.';
    }
    return $result;
}

// add minimum price on congress tickets for non-members
add_filter( 'gform_field_validation_19_20', 'gf_user_defined_price_validation_tickets_nonmembers', 10, 4 );
function gf_user_defined_price_validation_tickets_nonmembers( $result, $value, $form, $field ) {
    //change value for price field to just be numeric (strips off currency symbol, etc.) using Gravity Forms to_number function
    $number = GFCommon::to_number( $value, 'EUR' );
    GFCommon::log_debug( __METHOD__ . '(): User Defined Price Submitted: ' . $number );
  
	$min_amount = 15.00;
    if ( $result['is_valid'] && $number < $min_amount ) {
        $result['is_valid'] = false;
        $result['message'] = 'Je kan geen bedrag invullen lager dan '.$min_amount.' euro.';
    }
    return $result;
}
